@@ -382,6 +382,29 @@ class SettingsEDI {
 			),
 		);
 		
+		// Peppol specific field
+		$settings_fields[] = array(
+			'type'     => 'setting',
+			'id'       => 'peppol_directory_validation',
+			'title'    => '',
+			'callback' => 'checkbox',
+			'section'  => $section,
+			'args'     => array(
+				'title'       => __( 'Validate customer Endpoint ID', 'woocommerce-pdf-invoices-packing-slips' ),
+				'option_name' => $option_name,
+				'id'          => 'peppol_directory_validation',
+				'description' => __(
+					'When enabled, the customer Peppol Endpoint ID entered at checkout is validated against the Peppol Directory. If no matching participant is found, an error is shown so the value can be corrected.',
+					'woocommerce-pdf-invoices-packing-slips'
+				),
+				'custom_attributes' => array(
+					'data-show_for_option_name'   => $option_name . '[ubl_format]',
+					'data-show_for_option_values' => wp_json_encode( array( 'peppol-bis-3p0' ) ),
+					'data-keep_current_value'     => true,
+				),
+			),
+		);
+		
 		$languages = wpo_wcpdf_get_multilingual_languages();
 
 		if ( count( $languages ) > 0 ) {
@@ -854,7 +877,7 @@ class SettingsEDI {
 						printf(
 							/* translators: %1$s: open link anchor, %2$s: close link anchor */
 							esc_html__( 'For more information on setting up the tax table, please see our %1$sarticle%2$s.', 'woocommerce-pdf-invoices-packing-slips' ),
-							'<a href="https://docs.wpovernight.com/woocommerce-pdf-invoices-packing-slips/configuring-tax-classifications-for-e-documents-en16931/" target="_blank" rel="noopener noreferrer">', // TODO: add link
+							'<a href="https://docs.wpovernight.com/e-documents/configuring-tax-classifications-for-e-documents/" target="_blank" rel="noopener noreferrer">',
 							'</a>'
 						);
 					?>
